# OctoPrintDeviceRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**model** | **str** |  | 
**platform** | **str** |  | 
**cpu_flags** | **list[str]** |  | [optional] 
**hardware** | **str** |  | [optional] 
**revision** | **str** |  | [optional] 
**serial** | **str** |  | 
**cores** | **int** |  | 
**ram** | **int** |  | 
**python_version** | **str** |  | 
**pip_version** | **str** |  | 
**virtualenv** | **str** |  | [optional] 
**octoprint_version** | **str** |  | 
**plugin_version** | **str** |  | 
**print_nanny_client_version** | **str** |  | 
**print_nanny_beta_client_version** | **str** |  | [optional] 
**active_session** | [**PrintSessionRequest**](PrintSessionRequest.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


